CurveType enum
Supported elliptic curve types for DIDComm cryptography.
- Inheritance
- Available extensions
- Annotations
-
- @JsonEnum.new(valueField: 'value')
Values
- p256 → const CurveType
-
NIST P-256 curve (also known as secp256r1).
const CurveType('P-256', 32) - p384 → const CurveType
-
Represents the NIST P-384 elliptic curve, also known as secp384r1.
const CurveType('P-384', 48) - p521 → const CurveType
-
Represents the NIST P-521 elliptic curve, also known as secp521r1.
const CurveType('P-521', 66) - secp256k1 → const CurveType
-
SECG secp256k1 curve.
const CurveType('secp256k1', 32) - x25519 → const CurveType
-
X25519 curve.
const CurveType('X25519', 32)
Properties
- coordinateLength → int
-
The length of the coordinate in bytes for this curve type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The string value of the curve, as used in JWKs and headers.
final
Methods
-
asKeyType(
) → KeyType -
Available on CurveType, provided by the CurveTypeExtension extension
Maps a CurveType to a compatibleKeyTypefor DIDComm operations. -
isSecp256OrPCurve(
) → bool - Returns true if this curve is a P-curve or secp256k1 (used for ECDH-ES/ECDH-1PU).
-
isXCurve(
) → bool - Returns true if this curve is an X-curve (X25519).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited