IncompatibleEncryptionAlgorithmWithAuthcrypt class
Thrown when A256GCM or XC20P is used with authcrypt (ECDH-1PU) which is not allowed by DIDComm specification.
This error indicates that the provided EncryptionAlgorithm is incompatible with the KeyWrappingAlgorithm.ecdh1Pu (authenticated encryption). Only A256CBC-HS512 is allowed for use with authcrypt according to the DIDComm specification.
- Inheritance
-
- Object
- Error
- UnsupportedError
- IncompatibleEncryptionAlgorithmWithAuthcrypt
Constructors
- IncompatibleEncryptionAlgorithmWithAuthcrypt(EncryptionAlgorithm encryptionAlgorithm)
-
Creates an IncompatibleEncryptionAlgorithmWithAuthcrypt error for the given
encryptionAlgorithm.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited