LiveDeliveryChangeMessageOptions class
Options for sending a live delivery change message over a DIDComm mediator.
Allows configuration of whether to send the message and how it should be protected (signing, encryption, etc).
- Inheritance
-
- Object
- MessageOptions
- LiveDeliveryChangeMessageOptions
Constructors
- LiveDeliveryChangeMessageOptions({bool shouldSend = false, bool shouldSign = false, bool shouldEncrypt = true, EncryptionAlgorithm encryptionAlgorithm = EncryptionAlgorithm.a256cbc, KeyWrappingAlgorithm keyWrappingAlgorithm = KeyWrappingAlgorithm.ecdhEs})
-
Constructs LiveDeliveryChangeMessageOptions.
const
Properties
- encryptionAlgorithm → EncryptionAlgorithm
-
The encryption algorithm to use for message content.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyWrappingAlgorithm → KeyWrappingAlgorithm
-
The key wrapping algorithm to use for encryption.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldEncrypt → bool
-
Whether the message should be encrypted.
finalinherited
- shouldSend → bool
-
Whether a live delivery change message should be sent.
final
- shouldSign → bool
-
Whether the message should be signed.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited